#
# spec file for package kdeconnect-kde
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without  lang
# Latest stable Applications (e.g. 17.08 in KA, but 17.11.80 in KUA)
%{!?_kapp_version: %define _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
Name:           kdeconnect-kde
Version:        20.04.2
Release:        lp152.2.3.1
Summary:        Integration of Android with Linux desktops
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
URL:            https://community.kde.org/KDEConnect
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
%endif
Source100:      kdeconnect-kde.SuSEfirewall
Source101:      kdeconnect-kde-firewalld.xml
# PATCH-FIX-UPSTREAM
Patch0:         0001-Use-ecm_qt_declare_logging_category-to-declare-the-l.patch
Patch1:         0001-Do-not-leak-the-local-user-in-the-device-name.patch
Patch2:         0002-Fix-use-after-free-in-LanLinkProvider-connectError.patch
Patch3:         0003-Limit-identity-packets-to-8KiB.patch
Patch4:         0004-Do-not-let-lanlink-connections-stay-open-for-long-wi.patch
Patch5:         0005-Don-t-brute-force-reading-the-socket.patch
Patch6:         0006-Limit-number-of-connected-sockets-from-unpaired-devi.patch
Patch7:         0007-Do-not-remember-more-than-a-few-identity-packets-at-.patch
Patch8:         0008-Limit-the-ports-we-try-to-connect-to-to-the-port-ran.patch
Patch9:         0009-Do-not-replace-connections-for-a-given-deviceId-if-t.patch
BuildRequires:  cmake >= 3.0
BuildRequires:  extra-cmake-modules
BuildRequires:  kf5-filesystem
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5Declarative)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5KCMUtils)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Kirigami2)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5People)
BuildRequires:  cmake(KF5PeopleVCard)
BuildRequires:  cmake(KF5PulseAudioQt)
BuildRequires:  cmake(KF5Wayland)
BuildRequires:  cmake(Qca-qt5)
BuildRequires:  cmake(Qt5Multimedia)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libfakekey)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xtst)
Requires:       sshfs
Recommends:     %{name}-lang = %{version}
Recommends:     kpeoplevcard
Conflicts:      kdeconnect-kde4

%description
A package for integration of Android with Linux desktops.

Current feature list:
- Clipboard share: copy from or to your desktop
- Notifications sync (4.3+): Read your Android notifications
- Multimedia remote control: Use your phone as a remote control
- WiFi connection: no USB wire or Bluetooth needed
- RSA Encryption: your information is safe

Please note you will need to install KDE Connect on Android for this app to work:
https://play.google.com/store/apps/details?id=org.kde.kdeconnect_tp or
https://f-droid.org/en/packages/org.kde.kdeconnect_tp/

%package zsh-completion
Summary:        ZSH completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:zsh)
BuildArch:      noarch

%description zsh-completion
ZSH command line completion support for %{name}.

%lang_package

%prep
%setup -q
%autopatch -p1

%build
%cmake_kf5 -d build
%make_jobs

%install
%kf5_makeinstall -C build

%if %{with lang}
for translation_file in kdeconnect-{app,cli,core,fileitemaction,indicator,interfaces,kcm,kded,kio,nautilus-extension,plugins,settings,sms,urlhandler} plasma_applet_org.kde.kdeconnect; do
    %find_lang $translation_file %{name}.lang
done
%kf5_find_htmldocs
%endif

%if 0%{?suse_version} < 1550
# susefirewall config file
install -D -m 0644 %{SOURCE100} \
    %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{name}
%endif
# firewalld config file
install -D -m 0644 %{SOURCE101} \
    %{buildroot}%{_libexecdir}/firewalld/services/%{name}.xml

%suse_update_desktop_file %{buildroot}%{_kf5_applicationsdir}/org.kde.kdeconnect.app.desktop Network RemoteAccess
%suse_update_desktop_file %{buildroot}%{_kf5_applicationsdir}/org.kde.kdeconnect.nonplasma.desktop Network RemoteAccess
%suse_update_desktop_file %{buildroot}%{_kf5_applicationsdir}/org.kde.kdeconnect_open.desktop Network RemoteAccess

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_kdeconnect

%files
%license COPYING
%doc README*
%if 0%{?suse_version} < 1550
%config(noreplace) %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{name}
%endif
%dir %{_datadir}/Thunar
%dir %{_datadir}/contractor
%dir %{_datadir}/nautilus-python
%dir %{_libexecdir}/firewalld
%dir %{_libexecdir}/firewalld/services
%{_datadir}/Thunar/sendto/
%{_datadir}/contractor/kdeconnect.contract
%{_datadir}/nautilus-python/extensions/
%{_libexecdir}/firewalld/services/%{name}.xml
%{_kf5_libdir}/libkdeconnect*.so.*
%{_kf5_plugindir}/
%{_kf5_applicationsdir}/*.desktop
%dir %{_kf5_iconsdir}/hicolor/256x256
%dir %{_kf5_iconsdir}/hicolor/256x256/apps
%{_kf5_iconsdir}/hicolor/*/apps/kdeconnect*
%{_kf5_libdir}/libexec/
%{_kf5_servicesdir}/
%{_kf5_notifydir}/
%{_kf5_servicetypesdir}/
%{_kf5_sharedir}/plasma/
%{_kf5_qmldir}/
%{_kf5_bindir}/kdeconnect-app
%{_kf5_bindir}/kdeconnect-cli
%{_kf5_bindir}/kdeconnect-handler
%{_kf5_bindir}/kdeconnect-indicator
%{_kf5_bindir}/kdeconnect-settings
%{_kf5_bindir}/kdeconnect-sms
%{_kf5_sharedir}/dbus-1/services/org.kde.kdeconnect.service
%{_kf5_configdir}/autostart/org.kde.kdeconnect.daemon.desktop
%{_kf5_iconsdir}/hicolor/*/status/*
%{_kf5_htmldir}/en/kdeconnect/
%dir %{_kf5_appstreamdir}
%{_kf5_appstreamdir}/org.kde.kdeconnect.kcm.appdata.xml
%{_kf5_debugdir}/kdeconnect-kde.categories

%if %{with lang}
%files lang -f %{name}.lang
%endif

%changelog
* Fri Oct  2 2020 Luca Beltrame <lbeltrame@kde.org>
- Add upstream patches to fix security issues in kdeconnect
  (CVE-2020-26164, boo#1176268):
  * 0001-Do-not-leak-the-local-user-in-the-device-name.patch
  * 0002-Fix-use-after-free-in-LanLinkProvider-connectError.patch
  * 0003-Limit-identity-packets-to-8KiB.patch
  * 0004-Do-not-let-lanlink-connections-stay-open-for-long-wi.patch
  * 0005-Don-t-brute-force-reading-the-socket.patch
  * 0006-Limit-number-of-connected-sockets-from-unpaired-devi.patch
  * 0007-Do-not-remember-more-than-a-few-identity-packets-at-.patch
  * 0008-Limit-the-ports-we-try-to-connect-to-to-the-port-ran.patch
  * 0009-Do-not-replace-connections-for-a-given-deviceId-if-t.patch
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- Changes since 20.04.1:
  * Fix findthisdevice sound URL
  * Remove windows CI in stable too
* Wed May 27 2020 Antonio Larrosa <alarrosa@suse.com>
- Add patch submitted upstream to use
  ecm_qt_declare_logging_category so users can easily modify the
  debugging configuration and use a default logging level of
  Warning instead of sending all debug messages to the log:
  * 0001-Use-ecm_qt_declare_logging_category-to-declare-the-l.patch
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * Unmute audio when volume changes (kde#408705)
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- No code change since 20.03.90
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- Changes since 20.03.80:
  * Exception doesn't have strerr
  * Check for null notification
  * [fileitemactionplugin] Use async DBus call (kde#419133)
  * Improve call notification handling
  * Read payload size as qint64
  * Use kdeconnect-settings for command configuration
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * kdeconnect-kde is now part of the KDE applications release
    service
* Sat Jan 25 2020 wbauer@tmo.at
- Update to 1.4
  * New "KDE Connect" desktop app to control the phone from the PC
  * SMS app that can read and write SMS texts
  * control PC system's global volume from a phone
  * flip forward and back through presentation slides
  * compatibility with Thunar (Xfce's file manager) and Elementary
    applications such as Pantheon Files.
- Run spec-cleaner
* Tue Jul 30 2019 wbauer@tmo.at
- Update to 1.3.5
  * Add detectPlatform to always use wayland in a wayland session
  * i18n: fix extraction of nautilus extension
  * Don't update new notifications
  * Install desktop file for kdeconnectd
  * [sftp] Fix error message wording
  * Change plugin name
  * [sftp] Give better error messages for common errors
  * [sftp] Improve error reporting
  * Use KAboutData to set information about the daemon
  * Disable session management
  * Print socket error when connection fails
  * [kio] Mount device during stat if necessary
  * [backends/lan] Don't fail silently when a UDP packet could not
    be unserialized
  * Fix crash in daemon
  * Fix crash in notifications plugin (kde#400010)
  * Don't show multiple windows when replying to a notification
- Drop Leap 42.3 specific patches, it's no longer supported:
  * 0001-Fix-build-on-Leap-42.3.patch
  * 0001-Revert-Retry-the-network-packet-if-it-failed-to-unse.patch
- Don't install SuSEfirewall2 file on Tumbleweed anymore, Sf2 has
  been dropped
* Mon Apr  1 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Mon Mar 25 2019 wbauer@tmo.at
- Update to 1.3.4
  * Always play when call ended (kde#400787)
  * [cli] Show all reachable devices (kde#402088)
  * [sftp] Get device ID from URL
  * Retry the network packet if it failed to unserialize
  * Fix sending keys via CLI
  * [kio] Fix file browsing with non-KIO file managers
- Run spec-cleaner
- Refresh 0001-Fix-build-on-Leap-42.3.patch
- Add 0001-Revert-Retry-the-network-packet-if-it-failed-to-unse.patch
  to make it build on Leap 42.3
- Drop Provides/Obsoletes for kdeconnect-kde-devel, that package
  doesn't exist anymore since 2015 and nothing should need it
* Wed Nov 14 2018 wbauer@tmo.at
- Add 0001-Fix-build-on-Leap-42.3.patch to make it build on Leap
  42.3
* Wed Nov  7 2018 wbauer@tmo.at
- Update to 1.3.3
  * Instantiate QApplication object to fix crash on KDE Neon
    (kde#400178)
  * Fix build failure on musl based systems (kde#395161)
* Thu Oct 18 2018 wbauer@tmo.at
- Update to 1.3.2
  * Also allow modern algorithms, for compat with future apps
  * Remove characters from UUID that aren't legal in URLs
  * Add new notifications at the top of the list
  * Change the 'Dismiss all notifications' icon
  * Fix DBus signals in Mprisremote
* Fri Jun  1 2018 wbauer@tmo.at
- Update to 1.3.1
  * Fix a bug that would hang Nautilus when copying a file if
    paired devices were available
  * Fix remote filesystem reconnection issue
  * Add a missing dependency check in cmake
  * Add missing notification category to the plasmoid
- Mark license file with %%license instead of %%doc
* Mon Apr  9 2018 kamikazow@opensuse.org
- Update to 1.3.0
  * Fixed frequent crash when receiving notifications
  * Fixed MPRIS player entries never being deleted
  * Added a Gnome Files (Nautilus) extension to send files from the
    context menu
  * Added handling of "tel:" links with KDE Connect
  * Support sending album art in MPRIS plugin
  * Allow sharing more than one file from the CI (eg: --share *.mp3)
- Remove patches, now upstream:
  * 0001-Fix-null-dereference.patch
- Modified wording in Description to match that KDE Connect
  runs under any Linux desktop (see upstream README.md file)
* Tue Feb 20 2018 alarrosa@suse.com
- Add 0001-Fix-null-dereference.patch to fix a null dereference.
- Add signature file kdeconnect-kde-v1.2.1.tar.xz.sig
* Thu Jan 18 2018 wbauer@tmo.at
- Update to 1.2.1
  * Require the latest version of KF5
  * Was getting a double-delete, now it won't crash
  * Get rid of ProcessRunner
  * Add album art to mpris network packets
  * Add title, artist and album to MPRIS network packets
  * Fix information leak via /tmp (kde#383144)
  * Add support for new Android 2.3 (API 9+) cipher
  * Fix kdeconnect-cli device list
  * Fix "error activiting kdeconnectd" for kdeconnect-cli
  * Delay kdeconnectd autostart phase
  * Fix Notifications in Plasmoid
  * Make sure there's not a path within the filename
  * share plugin: fix path display
  * Use pactl instead of KMix in PauseMusic Plugin
- needs KDE Frameworks 5.42 now
* Sun Oct  1 2017 wbauer@tmo.at
- Update to 1.2.0
- Update build requirements, it needs Qt 5.7 and KF 5.38 now
- Remove patches, now upstream:
  * 0001-Treat-device-names-as-plaintext-not-rich-text.patch
* Wed Jul 12 2017 fabian@ritter-vogt.de
- Add patch to fix unauthenticated HTML injection (kde#382243):
  * 0001-Treat-device-names-as-plaintext-not-rich-text.patch
* Fri Dec 23 2016 ecsos@opensuse.org
- Update to 1.0.3
* Sat Nov 12 2016 hrvoje.senjan@gmail.com
- Update to 1.0.2
* Wed Sep 21 2016 wbauer@tmo.at
- Update to 1.0.1
  * fixes some issues found in 1.0
- Drop upstreamed fix-build-with-older-qt.patch
* Wed Sep  7 2016 wbauer@tmo.at
- Add fix-build-with-older-qt.patch from upstream to make it
  compile with Qt < 5.6, and lower the Qt requirement to 5.2 again
  (as demanded by CMakeLists.txt)
* Fri Aug 26 2016 herbert@graeber-clan.de
- Add firewalld service file
* Fri Aug 26 2016 fabian@ritter-vogt.de
- Build docs again
- Require at least Qt 5.6
* Fri Aug 26 2016 lbeltrame@kde.org
- New upstream version 1.0
  * Trigger custom commands from phone
  * Reply to SMS messages from the desktop
  * Receive desktop notifications on phone
  * TLS encryption
* Mon Feb  1 2016 hrvoje.senjan@gmail.com
- Update to 0.9g
  * No changelog provided
- Drop upstreamed 0001-This-syntax-also-works-on-older-OpenSSH-versions.patch
* Thu Jan 14 2016 alarrosa@suse.com
- Add 0001-This-syntax-also-works-on-older-OpenSSH-versions.patch from
  upstream to be compatible with older openssh versions (bnc#961554)
* Mon Nov 30 2015 toddrme2178@gmail.com
- Update to 0.9f
  * Adds translations
- Update to 0.9
  * KF5 version
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 0.8
  * No changelog provided
* Mon Jan 12 2015 tittiatcoke@gmail.com
- Add Requires:  sshfs  to make it work.
* Thu Oct 16 2014 hrvoje.senjan@gmail.com
- Update to 0.7.3:
  * No changelog provided
* Fri Sep 12 2014 hrvoje.senjan@gmail.com
- Update to 0.7.2:
  * No changelog provided
* Tue Jul  1 2014 fisiu@opensuse.org
- Update to 0.7.1:
  * Touchpad allows to scroll with 2 fingers, middle and right click.
  * Minor fixes.
* Sat Jun 28 2014 fisiu@opensuse.org
- Update to 0.7:
  * Use phone as cursor controller.
  * Allow android phone to receive files from PC.
  * Many bug fixes.
  * Translation available in 25 languages.
* Fri May 16 2014 hrvoje.senjan@gmail.com
- Update to 0.5.2.1
  * New upstream release, no changelog provided
* Sun Mar  9 2014 hrvoje.senjan@gmail.com
- Update to 0.5.1
  * New upstream release, no changelog provided
* Sat Feb 22 2014 fisiu@opensuse.org
- Update to 0.5.
- Build language package.
* Sat Dec 21 2013 fisiu@opensuse.org
- Add kdeconnect-kde.SuSEfirewall: config file for SuSEfirewall2.
* Fri Dec 20 2013 fisiu@opensuse.org
- Update to 0.4.2:
  * Plasmoid now displays the devices' battery.
  * Added standalone binary to run kdeconnect without kded.
  * Added a config dialog to pausemusic plugin.
  * Share plugin changed name.
  * The battery percentage for low battery level is now signaled by the device.
* Mon Nov 11 2013 hrvoje.senjan@gmail.com
- Update to version 0.4.1
  * New feature release, no changelog provided
* Tue Nov  5 2013 hrvoje.senjan@gmail.com
- Update to version 0.4
  * New feature release, no changelog provided
- Remove lang tar, translations removed also from tar
- BuildRequire libqjson-devel >= 0.8, as it doesn't build with older
  QJson
* Thu Oct  3 2013 hrvoje.senjan@gmail.com
- Update to version 0.3
  * New feature release
- Added lang tarball
* Mon Sep  9 2013 toddrme2178@gmail.com
- Initial version (0.1)
